import Color from "./dist/color.js";
import rgbHex from './dist/rgb-hex.js';

ODA({ is: 'oda-color-picker-oklch',
    template: `
        <style>
            :host {
                @apply --horizontal;
                @apply --border;
                @apply --shadow;
                position: relative;
                max-width: {{width + (showPalette ? height : 0)}}px;
                width: {{width + (showPalette ? height : 0)}}px;
                height: {{height}}px;
            }
            label {
                width: 18px;
                text-align: center;
            }
            input {
                @apply --flex;
                border: none;
                outline: none;
            }
            .color-ranges {
                align-items: center;
                margin: 2px;
                font-size: 14px;
            }
            .color-ranges input {
                appearance: none;
                height: {{rangeH}}px;
                width: 100%;
                border-radius: 8px;
                box-shadow: inset 0px 0px 15px 5px rgba(0, 0, 0, 0.1);
            }
            input::-webkit-slider-thumb {
                -webkit-appearance: none;
                appearance: none;
                width: {{rangeH-4}}px;
                height: {{rangeH-4}}px;
                background: white;
                border-radius: 50%;
                cursor: pointer;
            }
            input.lightness {
                background: linear-gradient(90deg, oklch(0 {{c}} {{h}}) 0%, oklch(1 {{c}} {{h}}) 100%);
            }
            input.chroma {
                background: linear-gradient(90deg, oklch({{l}} 0 {{h}}) 0%, oklch({{l}} .37 {{h}}) 100%);
            }
            input.hue {
                background: linear-gradient(90deg, oklch({{l}} {{c}} 0) 0%, oklch({{l}} {{c}} 36) 10%,oklch({{l}} {{c}} 72) 20%, oklch({{l}} {{c}} 108) 30%, oklch({{l}} {{c}} 144) 40%, oklch({{l}} {{c}} 180) 50%, oklch({{l}} {{c}} 216) 60%, oklch({{l}} {{c}} 252) 70%, oklch({{l}} {{c}} 288) 80%, oklch({{l}} {{c}} 324) 90%, oklch({{l}} {{c}} 360) 100%);
            }
            input.alpha {
                background: linear-gradient(90deg, oklch({{l}} {{c}} {{h}} / 0) 0%, oklch({{l}} {{c}} {{h}} / 1) 100%);
            }
            .palette {
                box-sizing: border-box;
                width: {{height}};
                min-width: {{height}};
                max-height: {{height}};
                height: {{height}};
            }
            .convertor {
                box-sizing: border-box;
                width: {{width - 8}}px;
                height: {{height - 46}}px;
                position: absolute;
                background: var(--content-background);
                left: 4px;
                top: 4px;
            }
            .cell {
                box-sizing: border-box;
                cursor: pointer;
                width: {{(height - 10) / 10}}px;
                height: {{(height - 10) / 10}}px;
            }
            .btn {
                opacity: .1;
            }
            .btn:hover {
                opacity: .5;
            }
            .result {
                background-image: 
                    linear-gradient(45deg, #eee 25%, transparent 25%, transparent 75%, #eee 75%, #eee 100%),
                    linear-gradient(45deg, #eee 25%, white 25%, white 75%, #eee 75%, #eee 100%);
                background-position: 0px 0px, 10px 10px;
                background-size: 20px 20px;
                overflow: hidden;    
            }
        </style>
        <div ~if="showColors" class="vertical border" ~style="{width: width - 8 + 'px', height: height -10 + 'px'}" style="position: absolute; z-index: 1; margin: 4px; border-radius: 4px; background: var(--content-background); height: 100%;">
            <div class="horizontal">
                <input id="search" type="search" style="border-bottom: 1px solid  var(--border-color)" @input="searchString = $('#search').value">
                <oda-button icon="bootstrap:search" icon-size="16" @tap="searchString = $('#search').value"></oda-button>
            </div>
            <div class="verticl flex" style="overflow: hidden; overflow-y: auto;">
                <div class="horizontal" ~for="isRusColors ? rusColors : namedColors" style="align-items: center; cursor: pointer;" @tap="_selectColor($for.item.v || $for.item)">
                    <div style="min-width: 60px; max-width: 60px; height: 32px; margin: 4px;" ~style="{background:  $for.item.v || $for.item}"></div>
                    <div style="overflow-wrap: anywhere; white-space: normal; font-size: 14px; padding: 4px;">{{$for.item.l || $for.item}}</div>
                </div>
            </div>
            <div class="horizontal">
                <oda-button class="border" style="margin: 4px; border-radius: 4px;"  @tap="isRusColors=!isRusColors; $('#search').value = this.searchString = '';" allow-toggle ::toggled="isRusColors">rus</oda-button>
                <oda-button class="flex border" icon="iconoir:cancel" style="margin: 4px; border-radius: 4px;"  @tap="showColors=false; $('#search').value = this.searchString = '';">cancel</oda-button>
            </div>
        </div>
        <div class="vertical" ~style="{minWidth: width - 8 + 'px'}" style="margin: 4px; border-radius: 4px;">
            <div class="result horizontal flex border">
                <div style="width: 30%; height: 100%; cursor: pointer" ~style="{background: srcValue || value}" @tap="srcValue=value"></div>
                <div class="flex" style="cursor: pointer" ~style="{backgroundColor: value}" @tap="srcValue=''"></div>
            </div>
            <input id="inp" class="no-flex border" type="text" :value="value" style="padding: 2px; font-size: 15px; margin: 4px 0; text-align: center;" @change="setValue">
            <div class="color-ranges h">
                <label>l</label>
                <input type="range" class="lightness" ::value="l" min="0" max="1" step="0.01">
            </div>
            <div class="color-ranges h">
                <label>c</label>
                <input type="range" class="chroma" ::value="c" min="0" max="0.37" step="0.001">
            </div>
            <div class="color-ranges h">
                <label>h</label>
                <input type="range" class="hue" ::value="h" min="0" max="360" step="1">
            </div>
            <div class="color-ranges h" style="margin-bottom: 4px;">
                <label>a</label>
                <input type="range" class="alpha" ::value="a" min="0" max="1" step="0.01">
            </div>
            <div class="color-input vertical">
                <div ~if="storeLength > 0" class="vertical flex" style="cursor: pointer">
                    <div class="horizontal flex" style="width: 100%">
                        <div ~for="storeLength" class="border" style="width: 100%;margin-right: 2px; margin-bootom: 1px;" @mousedown="_storeDown($event, $for.index)" @pointerup="_storeUp($event, $for.index)" ~style="{background: store?.['s'+$for.index] || '', height: (storeH || 16)+'px'}"></div>
                    </div>
                    <div class="horizontal flex">
                        <div ~for="storeLength" class="border" style="width: 100%;margin-right: 2px; margin-top: 1px;" @mousedown="_storeDown($event, $for.index+storeLength)" @pointerup="_storeUp($event, $for.index+storeLength)" ~style="{background: store?.['s'+($for.index+storeLength)] || '', height: (storeH || 16)+'px'}"></div>
                    </div>
                </div>
                <div class="horizontal" style="justify-content: flex-end; margin: 4px 1px 1px 1px;">
                    <oda-button icon="carbon:clean" class="border flex" style="margin-right: 4px; padding: 4px; border-radius: 4px;"  @tap="_clear" title="clear history"></oda-button>
                    <oda-button icon="box:s-color-fill" class="border flex" style="margin-right: 4px; padding: 4px; border-radius: 4px;"  @tap="showColors = true" title="select colors"></oda-button>
                    <oda-button icon="carbon:copy" class="border flex" style="margin-right: 4px; padding: 4px; border-radius: 4px;"  allow-toggle ::toggled="showConvertor" title="show convertor"></oda-button>
                    <oda-button icon="carbon:color-palette" class="border flex" style="margin-right: 4px; padding: 4px; border-radius: 4px;"  allow-toggle ::toggled="showPalette" title="show / hide palette"></oda-button>
                    <oda-button icon="iconoir:cancel" class="border flex" style="margin-right: 4px; padding: 4px; border-radius: 4px;"  @tap="_cancel" title="cancel"></oda-button>
                    <oda-button icon="bootstrap:check2-square" class="border flex" style="padding: 4px; border-radius: 4px;"  @tap="_ok" title="ok"></oda-button>
                </div>
            </div>
        </div>
        <div ~if="showPalette" class="palette horizontal center" style="flex-wrap: wrap; ">
            <div ~for="100" class="cell" ~style="{borderBottom: $for.index<90 ? '1px solid lightgray' : '', borderRight: ($for.index+1)%10 ? '1px solid lightgray' : '', background: 'oklch(' + ($for.index / 100) + ' ' + c + ' ' + h + ' / ' + (a >= 0 ? a : 1) + ')'}" @click="l = $for.index / 100"></div>
        </div>
        <div ~if="showConvertor" class="convertor vertical border">
            <div class="result horizontal flex" style="position: relative">
                <div class="flex" ~style="{backgroundColor: value}" style="border-bottom: 1px solid var(--border-color)"></div>
            </div>
            <div class="vertical" ~for="['oklch','srgb','hsl']" style="padding: 2px; border-bottom: 1px solid lightgray">
                <div class="horizontal flex" style="font-size: x-small; align-items: center">
                    <div class="flex">{{$for.item}}</div>
                    <oda-button class="btn" icon="carbon:copy" @tap="_copyToClipboard(vColor.to($for.item).toString())"></oda-button>
                </div>
                <div style="font-size: small; white-space: nowrap; text-overflow: ellipsis; overflow: hidden">{{vColor.to($for.item).toString()}}</div>
            </div>
            <div class="horizontal" style="font-size: x-small; align-items: center; margin: 2px">
                <div class="flex">hex</div>
                <oda-button class="btn" icon="carbon:copy" @tap="_copyToClipboard(rgbHexVal)"></oda-button>
            </div>
            <div style="font-size: small;  white-space: nowrap; text-overflow: ellipsis; overflow: hidden">{{rgbHexVal}}</div>
        </div>
    `,
    $public: {
        showPalette: {
            $def: false,
            $save: true
        },
        rangeH: {
            $def: 22,
            $save: true
        },
        l: {
            $def: 0,
            set(n) { this.refreshValue() },
            $save: true
        },
        c: {
            $def: 0,
            set(n) { this.refreshValue() },
            $save: true
        },
        h: {
            $def: 0,
            set(n) { this.refreshValue() },
            $save: true
        },
        a: {
            $def: .5,
            set(n) { this.refreshValue() },
            $save: true
        },
        width: {
            $def: 220,
            $save: true
        },
        height: {
            $def: 300,
            $save: true
        },
        storeLength: {
            $def: 10,
            $save: true
        },
        storeH: {
            $def: 16,
            $save: true
        },
        value: {
            $def: '',
            get() {
                if (this.a >= 0 && this.a < 1)
                    return `oklch(${this.l} ${this.c} ${this.h} / ${this.a})`;
                return `oklch(${this.l} ${this.c} ${this.h})`;
            }
        },
        srcValue: {
            $def: '',
            set(n) {
                this.setValue(n, true);
            }
        },
        clipValue: '',
        clickTime: 500,
        showConvertor: false,
        showColors: false,
        searchString: '',
        isRusColors: false
    },
    get namedColors() {
        return namedColors.filter(i => i.toLocaleLowerCase().includes(this.searchString.toLocaleLowerCase() || ''));
    },
    get rusColors() {
        return rusColors.filter(i => i.l.toLocaleLowerCase().includes(this.searchString.toLocaleLowerCase() || ''));
    },
    get vColor() {
        return new Color(this.value);
    },
    get rgbHex() {
        return rgbHex;
    },
    get rgbHexVal() {
        let val = rgbHex(this.vColor?.to('srgb').toString());
        return '#' + val;
    },
    store: {
        $def: undefined,
        $save: true
    },
    attached() {
        this._init();
        this.isReady = true;
    },
    _init() {
        this.store ||= {};
        let s = this.storeLength - 5;
        this.store['s' + (s + 0)] ||= 'oklch(0 0 0)';                   // black
        this.store['s' + (s + 1)] ||= 'oklch(.32 0 0)';                 // black lightness - 20%
        this.store['s' + (s + 2)] ||= 'oklch(.51 0 0)';                 // black lightness - 40%
        this.store['s' + (s + 3)] ||= 'oklch(.68 0 0)';                 // black lightness - 60%
        this.store['s' + (s + 4)] ||= 'oklch(.85 0 0)';                 // black lightness - 80%
        this.store['s' + (s * 2 + 5)] ||= 'oklch(0.63 0.258 29.23)';    // red
        this.store['s' + (s * 2 + 6)] ||= 'oklch(0.52 0.177 142.5)';    // green
        this.store['s' + (s * 2 + 7)] ||= 'oklch(0.45 0.313 264.05)';   // blue
        this.store['s' + (s * 2 + 8)] ||= 'oklch(0.99 0.04 107.11)';    // lightyellow
        this.store['s' + (s * 2 + 9)] ||= 'oklch(1 0 0)';               // white
    },
    refreshValue() {
        if (this.isReady)
            this.value = undefined;
    },
    setValue(e, skip) {
        this.refreshValue();
        let val = e?.target?.value || e || '';
        try {
            let color = new Color(val);
            let l = Math.round(color.oklch[0] * 100) / 100,
                c = Math.round(color.oklch[1] * 1000) / 1000,
                h = Math.round((color.oklch[2] || 0) * 100) / 100,
                a = Math.round(color.alpha * 100) / 100,
                _a = a >= 1 ? '' : ` / ${color.alpha}`;
            val = `oklch(${l} ${c} ${h}${_a})`;
            if (!skip)
                this.srcValue = val;
            this.l = l;
            this.c = c;
            this.h = h;
            this.a = a;
            this.value = val;
        } catch (err) { }
    },
    _storeDown(e, idx) {
        this.startStamp = e.timeStamp;
        this.async(() => {
            if (!this._setsValue)
                this.store['s' + idx] = this.value;
            this._setsValue = false;
        }, this.clickTime);
    },
    _storeUp(e, idx) {
        const ts = e.timeStamp - this.startStamp;
        this.store ||= {};
        if (ts < this.clickTime) {
            this._setsValue = true;
            this.setValue(this.store['s' + idx], true);
        }
        this.store = { ...this.store };
        this.async(() => this._setsValue = false, this.clickTime + 1);
    },
    _selectColor(color) {
        this.showColors = false;
        this.setValue(color, true);
        this.$('#search').value = this.searchString = '';
    },
    async _ok() {
        this.fire('ok', this.value);
        await navigator?.clipboard?.writeText(this.clipValue || this.value);
    },
    _cancel() {
        this.fire('cancel');
    },
    _clear() {
        this.store = {};
        // this._init();
    },
    async _copyToClipboard(v) {
        // console.log(v);
        this.clipValue = v;
        await navigator?.clipboard?.writeText(v);
    }
})


const namedColors = [
    `AliceBlue`,
    `AntiqueWhite`,
    `Aqua`,
    `Aquamarine`,
    `Azure`,
    `Beige`,
    `Bisque`,
    `Black`,
    `BlanchedAlmond`,
    `Blue`,
    `BlueViolet`,
    `Brown`,
    `BurlyWood`,
    `CadetBlue`,
    `Chartreuse`,
    `Chocolate`,
    `Coral`,
    `CornflowerBlue`,
    `Cornsilk`,
    `Crimson`,
    `Cyan`,
    `DarkBlue`,
    `DarkCyan`,
    `DarkGoldenRod`,
    `DarkGray`,
    `DarkGrey`,
    `DarkGreen`,
    `DarkKhaki`,
    `DarkMagenta`,
    `DarkOliveGreen`,
    `Darkorange`,
    `DarkOrchid`,
    `DarkRed`,
    `DarkSalmon`,
    `DarkSeaGreen`,
    `DarkSlateBlue`,
    `DarkSlateGray`,
    `DarkSlateGrey`,
    `DarkTurquoise`,
    `DarkViolet`,
    `DeepPink`,
    `DeepSkyBlue`,
    `DimGray`,
    `DimGrey`,
    `DodgerBlue`,
    `FireBrick`,
    `FloralWhite`,
    `ForestGreen`,
    `Fuchsia`,
    `Gainsboro`,
    `GhostWhite`,
    `Gold`,
    `GoldenRod`,
    `Gray`,
    `Grey`,
    `Green`,
    `GreenYellow`,
    `HoneyDew`,
    `HotPink`,
    `IndianRed`,
    `Indigo`,
    `Ivory`,
    `Khaki`,
    `Lavender`,
    `LavenderBlush`,
    `LawnGreen`,
    `LemonChiffon`,
    `LightBlue`,
    `LightCoral`,
    `LightCyan`,
    `LightGoldenRodYellow`,
    `LightGray`,
    `LightGrey`,
    `LightGreen`,
    `LightPink`,
    `LightSalmon`,
    `LightSeaGreen`,
    `LightSkyBlue`,
    `LightSlateGray`,
    `LightSlateGrey`,
    `LightSteelBlue`,
    `LightYellow`,
    `Lime`,
    `LimeGreen`,
    `Linen`,
    `Magenta`,
    `Maroon`,
    `MediumAquaMarine`,
    `MediumBlue`,
    `MediumOrchid`,
    `MediumPurple`,
    `MediumSeaGreen`,
    `MediumSlateBlue`,
    `MediumSpringGreen`,
    `MediumTurquoise`,
    `MediumVioletRed`,
    `MidnightBlue`,
    `MintCream`,
    `MistyRose`,
    `Moccasin`,
    `NavajoWhite`,
    `Navy`,
    `OldLace`,
    `Olive`,
    `OliveDrab`,
    `Orange`,
    `OrangeRed`,
    `Orchid`,
    `PaleGoldenRod`,
    `PaleGreen`,
    `PaleTurquoise`,
    `PaleVioletRed`,
    `PapayaWhip`,
    `PeachPuff`,
    `Peru`,
    `Pink`,
    `Plum`,
    `PowderBlue`,
    `Purple`,
    `Red`,
    `RosyBrown`,
    `RoyalBlue`,
    `SaddleBrown`,
    `Salmon`,
    `SandyBrown`,
    `SeaGreen`,
    `SeaShell`,
    `Sienna`,
    `Silver`,
    `SkyBlue`,
    `SlateBlue`,
    `SlateGray`,
    `SlateGrey`,
    `Snow`,
    `SpringGreen`,
    `SteelBlue`,
    `Tan`,
    `Teal`,
    `Thistle`,
    `Tomato`,
    `Turquoise`,
    `Violet`,
    `Wheat`,
    `White`,
    `WhiteSmoke`,
    `Yellow`,
    `YellowGreen`,
]

const rusColors = [
    { l: 'Абрикосовый', v: '#FBCEB1' },
    { l: 'Абрикосовый Крайола', v: '#FDD9B5' },
    { l: 'Агатовый серый', v: '#B5B8B1' },
    { l: 'Аквамариновый', v: '#7FFFD4' },
    { l: 'Аквамариновый Крайола', v: '#78DBE2' },
    { l: 'Ализариновый красный', v: '#E32636' },
    { l: 'Алый', v: '#FF2400' },
    { l: 'Амарантово-пурпурный', v: '#AB274F' },
    { l: 'Амарантово-розовый', v: '#F19CBB' },
    { l: 'Амарантовый', v: '#E52B50' },
    { l: 'Амарантовый глубоко-пурпурный', v: '#9F2B68' },
    { l: 'Амарантовый маджента', v: '#ED3CCA' },
    { l: 'Амарантовый светло-вишневый', v: '#CD2682' },
    { l: 'Американский розовый', v: '#FF033E' },
    { l: 'Аметистовый', v: '#9966CC' },
    { l: 'Античная латунь', v: '#CD9575' },
    { l: 'Антрацитово-серый', v: '#293133' },
    { l: 'Антрацитовый', v: '#464451' },
    { l: 'Арлекин', v: '#44944A' },
    { l: 'Аспидно-серый', v: '#2F4F4F' },
    { l: 'Аспидно-синий', v: '#6A5ACD' },
    { l: 'Бабушкины яблоки', v: '#A8E4A0' },
    { l: 'Базальтово-серый', v: '#4E5754' },
    { l: 'Баклажанный Крайола', v: '#614051' },
    { l: 'Баклажановый', v: '#990066' },
    { l: 'Баклажановый Крайола', v: '#6E5160' },
    { l: 'Бананомания', v: '#FAE7B5' },
    { l: 'Барвинок, перванш', v: '#CCCCFF' },
    { l: 'Барвинок Крайола', v: '#C5D0E6' },
    { l: 'Бедра испуганной нимфы', v: '#FAEEDD' },
    { l: 'Бежево-коричневый', v: '#79553D' },
    { l: 'Бежево-красный', v: '#C1876B' },
    { l: 'Бежево-серый', v: '#6D6552' },
    { l: 'Бежевый', v: '#F5F5DC' },
    { l: 'Бело-алюминиевый', v: '#A5A5A5' },
    { l: 'Бело-зеленый', v: '#BDECB6' },
    { l: 'Белоснежный', v: '#FFFAFA' },
    { l: 'Белый', v: '#FFFFFF' },
    { l: 'Белый антик', v: '#FAEBD7' },
    { l: 'Белый навахо', v: '#FFDEAD' },
    { l: 'Берлинская лазурь', v: '#003153' },
    { l: 'Бирюзово-голубой Крайола', v: '#77DDE7' },
    { l: 'Бирюзово-зеленый', v: '#1E5945' },
    { l: 'Бирюзово-синий', v: '#3F888F' },
    { l: 'Бирюзовый', v: '#30D5C8' },
    { l: 'Бисквитный', v: '#FFE4C4' },
    { l: 'Бисмарк-фуриозо', v: '#A5260A' },
    { l: 'Бистр', v: '#3D2B1F' },
    { l: 'Бледно-васильковый', v: '#ABCDEF' },
    { l: 'Бледно-желтый', v: '#FFDB8B' },
    { l: 'Бледно-зелено-серый', v: '#8D917A' },
    { l: 'Бледно-зеленый', v: '#89AC76' },
    { l: 'Бледно-золотистый', v: '#EEE8AA' },
    { l: 'Бледно-карминный', v: '#B03F35' },
    { l: 'Бледно-каштановый', v: '#DDADAF' },
    { l: 'Бледно-коричневый', v: '#755C48' },
    { l: 'Бледно-песочный', v: '#DABDAB' },
    { l: 'Бледно-пурпурный', v: '#F984E5' },
    { l: 'Бледно-розоватый', v: '#FFCBDB' },
    { l: 'Бледно-розовый', v: '#FADADD' },
    { l: 'Бледно-синий', v: '#AFEEEE' },
    { l: 'Бледно-фиолетовый', v: '#957B8D' },
    { l: 'Бледный весенний бутон', v: '#ECEBBD' },
    { l: 'Бледный желто-зеленый', v: '#F0D698' },
    { l: 'Бледный желто-розовый', v: '#FFC8A8' },
    { l: 'Бледный зеленовато-желтый', v: '#FFDF84' },
    { l: 'Бледный зеленый', v: '#98FB98' },
    { l: 'Бледный красно-пурпурный', v: '#AC7580' },
    { l: 'Бледный оранжево-желтый', v: '#FFCA86' },
    { l: 'Бледный пурпурно-розовый', v: '#FDBDBA' },
    { l: 'Бледный пурпурно-синий', v: '#8A7F8E' },
    { l: 'Бледный серо-коричневый', v: '#BC987E' },
    { l: 'Бледный синий', v: '#919192' },
    { l: 'Бледный фиолетово-красный', v: '#D87093' },
    { l: 'Блестящий желто-зеленый', v: '#CED23A' },
    { l: 'Блестящий желтовато-зеленый', v: '#8CCB5E' },
    { l: 'Блестящий желтый', v: '#FFCF40' },
    { l: 'Блестящий зеленовато-желтый', v: '#FFDC33' },
    { l: 'Блестящий зеленовато-синий', v: '#2A8D9C' },
    { l: 'Блестящий зеленый', v: '#47A76A' },
    { l: 'Блестящий оранжевый', v: '#FFB841' },
    { l: 'Блестящий пурпурно-розовый', v: '#FF97BB' },
    { l: 'Блестящий пурпурно-синий', v: '#62639B' },
    { l: 'Блестящий пурпурный', v: '#DD80CC' },
    { l: 'Блестящий синевато-зеленый', v: '#009B76' },
    { l: 'Блестящий синий', v: '#4285B4' },
    { l: 'Блестящий фиолетовый', v: '#755D9A' },
    { l: 'Блошиный (Красновато-коричневый)', v: '#755A57' },
    { l: 'Бобровый', v: '#9F8170' },
    { l: 'Болгарский розовый', v: '#480607' },
    { l: 'Болотный', v: '#ACB78E' },
    { l: 'Бордо (Красно-бордовый)', v: '#B00000' },
    { l: 'Бордово-фиолетовый', v: '#641C34' },
    { l: 'Бордовый', v: '#9B2D30' },
    { l: 'Бороды Абдель-Керима', v: '#D5D5D5' },
    { l: 'Брезентово-серый', v: '#4C514A' },
    { l: 'Бриллиантово-синий', v: '#3E5F8A' },
    { l: 'Бриллиантовый оранжево-желтый', v: '#FFB02E' },
    { l: 'Бронзовый', v: '#CD7F32' },
    { l: 'Бургундский', v: '#900020' },
    { l: 'Бурый', v: '#45161C' },
    { l: 'Бутылочно-зеленый', v: '#343B29' },
    { l: 'Ванильный', v: '#D5713F' },
    { l: 'Васильковый', v: '#6495ED' },
    { l: 'Васильковый Крайола', v: '#9ACEEB' },
    { l: 'Вердепешевый', v: '#DAD871' },
    { l: 'Вердепомовый', v: '#34C924' },
    { l: 'Вересково-фиолетовый', v: '#DE4C8A' },
    { l: 'Весенне-зеленый (Зеленая весна)', v: '#00FF7F' },
    { l: 'Весенне-зеленый Крайола', v: '#ECEABE' },
    { l: 'Весенний бутон', v: '#A7FC00' },
    { l: 'Византийский', v: '#BD33A4' },
    { l: 'Византия', v: '#702963' },
    { l: 'Винно-красный', v: '#5E2129' },
    { l: 'Винтовочный зеленый', v: '#414833' },
    { l: 'Вишневый (Вишня)', v: '#911E42' },
    { l: 'В меру оливково-коричневый', v: '#64400F' },
    { l: 'Водная синь', v: '#256D7B' },
    { l: 'Воды пляжа Бонди', v: '#0095B6' },
    { l: 'Восход солнца', v: '#FFCF48' },
    { l: 'Галечный серый', v: '#B8B799' },
    { l: 'Гейнсборо', v: '#DCDCDC' },
    { l: 'Гелиотроп (Гелиотроповый)', v: '#DF73FF' },
    { l: 'Георгиново-желтый', v: '#F3A505' },
    { l: 'Глиняный коричневый', v: '#734222' },
    { l: 'Глициния (Глициниевый)', v: '#C9A0DC' },
    { l: 'Глициния Крайола', v: '#CDA4DE' },
    { l: 'Глубокая фуксия Крайола', v: '#C154C1' },
    { l: 'Глубокий желто-коричневый', v: '#593315' },
    { l: 'Глубокий желто-розовый', v: '#F64A46' },
    { l: 'Глубокий желтовато-зеленый', v: '#00541F' },
    { l: 'Глубокий желтый', v: '#B57900' },
    { l: 'Глубокий желтый зеленый', v: '#425E17' },
    { l: 'Глубокий зеленовато-желтый', v: '#9F8200' },
    { l: 'Глубокий зеленый', v: '#004524' },
    { l: 'Глубокий карминно-розовый', v: '#EF3038' },
    { l: 'Глубокий карминный', v: '#A9203E' },
    { l: 'Глубокий коралловый', v: '#FF4040' },
    { l: 'Глубокий коричневый', v: '#4D220E' },
    { l: 'Глубокий красно-коричневый', v: '#490005' },
    { l: 'Глубокий красно-оранжевый', v: '#A91D11' },
    { l: 'Глубокий красно-пурпурный', v: '#641349' },
    { l: 'Глубокий красный', v: '#7B001C' },
    { l: 'Глубокий оливково-зеленый', v: '#142300' },
    { l: 'Глубокий оранжево-желтый', v: '#D76E00' },
    { l: 'Глубокий оранжевый', v: '#C34D0A' },
    { l: 'Глубокий пурпурно-красный', v: '#6F0035' },
    { l: 'Глубокий пурпурно-розовый', v: '#EB5284' },
    { l: 'Глубокий пурпурно-синий', v: '#1A153F' },
    { l: 'Глубокий пурпурный', v: '#531A50' },
    { l: 'Глубокий розовый', v: '#FF1493' },
    { l: 'Глубокий синевато-зеленый', v: '#00382B' },
    { l: 'Глубокий синий', v: '#002F55' },
    { l: 'Глубокий фиолетово-черный', v: '#240935' },
    { l: 'Глубокий фиолетовый', v: '#423189' },
    { l: 'Голубино-синий', v: '#606E8C' },
    { l: 'Голубой', v: '#42AAFF' },
    { l: 'Голубой (Морозное небо)', v: '#00BFFF' },
    { l: 'Голубой колокольчик Крайола', v: '#A2A2D0' },
    { l: 'Голубой Крайола', v: '#80DAEB' },
    { l: 'Горечавково-синий', v: '#0E294B' },
    { l: 'Горный луг', v: '#30BA8F' },
    { l: 'Городское небо (Пасмурно-небесный)', v: '#87CEEB' },
    { l: 'Горчичный', v: '#FFDB58' },
    { l: 'Горько-сладкий', v: '#FD7C6E' },
    { l: 'Гранатовый', v: '#F34723' },
    { l: 'Гранитовый серый (Гранитный)', v: '#2F353B' },
    { l: 'Графитно-черный', v: '#1C1C1C' },
    { l: 'Графитовый серый', v: '#474A51' },
    { l: 'Гридеперлевый', v: '#C7D0CC' },
    { l: 'Грузинский розовый', v: '#D71868' },
    { l: 'Грушево-зеленый', v: '#D1E231' },
    { l: 'Грушевый', v: '#EFD334' },
    { l: 'Гуммигут', v: '#E49B0F' },
    { l: 'Гусеница', v: '#B2EC5D' },
    { l: 'Дартмутский зеленый', v: '#00693E' },
    { l: 'Джазовый джем', v: '#CA3767' },
    { l: 'Джинсовый синий', v: '#1560BD' },
    { l: 'Дикая клубника Крайола', v: '#FF43A4' },
    { l: 'Дикий арбуз Крайола', v: '#FC6C85' },
    { l: 'Дикий синий Крайола', v: '#A2ADD0' },
    { l: 'Дымчато-белый', v: '#F5F5F5' },
    { l: 'Дынно-желтый', v: '#F4A900' },
    { l: 'Дыня Крайола', v: '#FDBCB4' },
    { l: 'Железно-серый', v: '#434B4D' },
    { l: 'Желтая сера', v: '#EDFF21' },
    { l: 'Желтая слоновая кость', v: '#E1CC4F' },
    { l: 'Желто-зеленый', v: '#9ACD32' },
    { l: 'Желто-зеленый Крайола', v: '#C5E384' },
    { l: 'Желто-золотой', v: '#CDA434' },
    { l: 'Желто-оливковый', v: '#47402E' },
    { l: 'Желто-оранжевый', v: '#ED760E' },
    { l: 'Желто-оранжевый Крайола', v: '#FFAE42' },
    { l: 'Желто-персиковый', v: '#FADFAD' },
    { l: 'Желто-розовый', v: '#FFE4B2' },
    { l: 'Желто-серый', v: '#8F8B66' },
    { l: 'Желтовато-белый', v: '#FFE2B7' },
    { l: 'Желтовато-серый', v: '#CAA885' },
    { l: 'Желтый', v: '#FFFF00' },
    { l: 'Желтый карри', v: '#9D9101' },
    { l: 'Желтый Крайола', v: '#FCE883' },
    { l: 'Желтый ракитник', v: '#D6AE01' },
    { l: 'Жемчужно-белый', v: '#EAE6CA' },
    { l: 'Жженый апельсин (Выгоревший оранжевый)', v: '#CC5500' },
    { l: 'Жимолость', v: '#CB6586' },
    { l: 'Защитно-синий', v: '#1E90FF' },
    { l: 'Защитный хаки (Камуфляжный)', v: '#78866B' },
    { l: 'Звезды в шоке', v: '#FF47CA' },
    { l: 'Зеленая лужайка', v: '#7CFC00' },
    { l: 'Зеленая сосна', v: '#01796F' },
    { l: 'Зеленая сосна Крайола', v: '#158078' },
    { l: 'Зелено-бежевый', v: '#BEBD7F' },
    { l: 'Зелено-желтый', v: '#ADFF2F' },
    { l: 'Зелено-желтый Крайола', v: '#F0E891' },
    { l: 'Зелено-коричневый', v: '#826C34' },
    { l: 'Зелено-лаймовый', v: '#BFFF00' },
    { l: 'Зелено-серый', v: '#4D5645' },
    { l: 'Зелено-синий', v: '#1F3438' },
    { l: 'Зелено-синий Крайола', v: '#1164B4' },
    { l: 'Зеленовато-белый', v: '#F5E6CB' },
    { l: 'Зеленовато-серый', v: '#7A7666' },
    { l: 'Зеленовато-черный', v: '#181513' },
    { l: 'Зеленоватый мокрый асфальт', v: '#4E5452' },
    { l: 'Зеленое море', v: '#2E8B57' },
    { l: 'Зеленые джунгли Крайола', v: '#3BB08F' },
    { l: 'Зеленые джунгли Крайола 90-го года', v: '#29AB87' },
    { l: 'Зеленый', v: '#008000' },
    { l: 'Зеленый Крайола', v: '#1CAC78' },
    { l: 'Зеленый лишайник, мох (Цвет зеленого мха)', v: '#ADDFAD' },
    { l: 'Зеленый Мичиганского университета', v: '#006633' },
    { l: 'Зеленый мох', v: '#2F4538' },
    { l: 'Зеленый орел', v: '#004953' },
    { l: 'Зеленый папоротник', v: '#4F7942' },
    { l: 'Зеленый трилистник', v: '#009A63' },
    { l: 'Зеленый чай', v: '#D0F0C0' },
    { l: 'Золотарник Крайола', v: '#FCD975' },
    { l: 'Золотисто-березовый', v: '#DAA520' },
    { l: 'Золотисто-каштановый', v: '#712F26' },
    { l: 'Золотой (Золотистый)', v: '#FFD700' },
    { l: 'Золотой Крайола', v: '#E7C697' },
    { l: 'Ивово-коричневый', v: '#321414' },
    { l: 'Известковая глина', v: '#79443B' },
    { l: 'Изумруд', v: '#009B77' },
    { l: 'Изумрудно-зеленый', v: '#287233' },
    { l: 'Изумрудный', v: '#50C878' },
    { l: 'Индиго', v: '#4B0082' },
    { l: 'Индиго Крайола', v: '#5D76CB' },
    { l: 'Индийский зеленый', v: '#138808' },
    { l: 'Индийский красный, каштановый', v: '#CD5C5C' },
    { l: 'Ирландский зеленый', v: '#4CBB17' },
    { l: 'Июньский бутон', v: '#BDDA57' },
    { l: 'Кадетский синий', v: '#5F9EA0' },
    { l: 'Кадетский синий Крайола', v: '#B0B7C6' },
    { l: 'Камелопардовый', v: '#A25F2A' },
    { l: 'Каменно-серый', v: '#8B8C7A' },
    { l: 'Канареечный (Ярко-желтый)', v: '#FFFF99' },
    { l: 'Капри синий', v: '#1B5583' },
    { l: 'Кардинал', v: '#C41E3A' },
    { l: 'Карибский зеленый', v: '#1CD3A2' },
    { l: 'Кармин', v: '#960018' },
    { l: 'Карминно-красный', v: '#A2231D' },
    { l: 'Карминно-розовый', v: '#EB4C42' },
    { l: 'Карминово-красный', v: '#FF0033' },
    { l: 'Каштаново-коричневый', v: '#633A34' },
    { l: 'Каштановый Крайола', v: '#BC5D58' },
    { l: 'Кварцевый', v: '#99958C' },
    { l: 'Кварцевый серый', v: '#6C6960' },
    { l: 'Киноварь', v: '#FF4D00' },
    { l: 'Кирпично-красный', v: '#CB4154' },
    { l: 'Кирпичный', v: '#884535' },
    { l: 'Китайский красный (Киноварь)', v: '#E34234' },
    { l: 'Кленовый зеленый', v: '#507D2A' },
    { l: 'Клубнично-красный', v: '#D53032' },
    { l: 'Кобальтово-синий', v: '#1E213D' },
    { l: 'Кобальт синий (Кобальтовый)', v: '#0047AB' },
    { l: 'Кожа буйвола (Палевый)', v: '#F0DC82' },
    { l: 'Кожура апельсина', v: '#FFA000' },
    { l: 'Кораллово-красный', v: '#B32821' },
    { l: 'Коралловый', v: '#FF7F50' },
    { l: 'Кордованский', v: '#893F45' },
    { l: 'Коричневато-оранжевый', v: '#B15124' },
    { l: 'Коричневато-розовый', v: '#CD9A7B' },
    { l: 'Коричневато-серый', v: '#503D33' },
    { l: 'Коричневато-черный', v: '#140F0B' },
    { l: 'Коричнево-бежевый', v: '#8A6642' },
    { l: 'Коричнево-бордовый', v: '#A52A2A' },
    { l: 'Коричнево-желтый цвета увядших листьев', v: '#C19A6B' },
    { l: 'Коричнево-зеленый', v: '#39352A' },
    { l: 'Коричнево-красный', v: '#781F19' },
    { l: 'Коричнево-малиновый', v: '#800000' },
    { l: 'Коричнево-малиновый Крайола', v: '#C8385A' },
    { l: 'Коричнево-оливковый', v: '#25221B' },
    { l: 'Коричневый', v: '#964B00' },
    { l: 'Коричневый Крайола', v: '#B4674D' },
    { l: 'Коричневый серый', v: '#464531' },
    { l: 'Коричневый цвета кожанного седла для лошади', v: '#8B4513' },
    { l: 'Коричный', v: '#7B3F00' },
    { l: 'Королевская фуксия', v: '#CA2C92' },
    { l: 'Королевский пурпурный Крайола', v: '#7851A9' },
    { l: 'Королевский синий', v: '#4169E1' },
    { l: 'Космические сливки', v: '#FFF8E7' },
    { l: 'Космос', v: '#414A4C' },
    { l: 'Кофейный', v: '#442D25' },
    { l: 'Крайоловый Абрикос', v: '#FDD5B1' },
    { l: 'Красно-буро-оранжевый', v: '#CD5700' },
    { l: 'Красно-желто-коричневый', v: '#80461B' },
    { l: 'Красно-коричневый', v: '#592321' },
    { l: 'Красно-оранжевый', v: '#C93C20' },
    { l: 'Красно-оранжевый Крайола', v: '#FF5349' },
    { l: 'Красно-сиреневый', v: '#6D3F5B' },
    { l: 'Красно-фиолетовый', v: '#922B3E' },
    { l: 'Красно-фиолетовый Крайола', v: '#C0448F' },
    { l: 'Красновато-серый', v: '#8B6C62' },
    { l: 'Красновато-черный', v: '#1E1112' },
    { l: 'Красное дерево', v: '#C04000' },
    { l: 'Красное дерево Крайола', v: '#CD4A4C' },
    { l: 'Красный', v: '#FF0000' },
    { l: 'Красный Крайола', v: '#EE204D' },
    { l: 'Красный песок', v: '#F4A460' },
    { l: 'Кремово-желтый', v: '#FFFDD0' },
    { l: 'Кремовый', v: '#FDF4E3' },
    { l: 'Кремовый хаки', v: '#C3B091' },
    { l: 'Кричащий зеленый', v: '#76FF7A' },
    { l: 'Крутой розовый Крайола', v: '#FB607F' },
    { l: 'Кукурузно-желтый', v: '#E4A010' },
    { l: 'Кукурузный', v: '#FBEC5D' },
    { l: 'Лаванда (Лавандовый)', v: '#E6E6FA' },
    { l: 'Лавандовый Крайола', v: '#FCB4D5' },
    { l: 'Лавандовый розовый', v: '#FBA0E3' },
    { l: 'Лазерный лимон', v: '#FEFE22' },
    { l: 'Лазурно-серый (Зеленовато-синий)', v: '#007BA7' },
    { l: 'Лазурно-синий', v: '#025669' },
    { l: 'Лазурный, Азур', v: '#007FFF' },
    { l: 'Лазурный Крайола', v: '#1DACD6' },
    { l: 'Лайм', v: '#00FF00' },
    { l: 'Лаймово-зеленый', v: '#32CD32' },
    { l: 'Ламантин', v: '#979AAA' },
    { l: 'Латунный', v: '#B5A642' },
    { l: 'Лесной волк', v: '#DBD7D2' },
    { l: 'Лесной зеленый', v: '#228B22' },
    { l: 'Ливерный', v: '#534B4F' },
    { l: 'Лиловый', v: '#DB7093' },
    { l: 'Лимонно-желтый', v: '#C7B446' },
    { l: 'Лимонно-желтый Крайола', v: '#FFF44F' },
    { l: 'Лимонно-кремовый', v: '#FFFACD' },
    { l: 'Лимонный', v: '#FDE910' },
    { l: 'Лиственно-зеленый', v: '#2D572C' },
    { l: 'Лиственный зеленый Крайола', v: '#6DAE81' },
    { l: 'Лососево-красный', v: '#D95030' },
    { l: 'Лососево-оранжевый', v: '#E55137' },
    { l: 'Лососевый', v: '#FF8C69' },
    { l: 'Лососевый Крайола', v: '#FF9BAA' },
    { l: 'Льняной', v: '#FAF0E6' },
    { l: 'Люминесцентный красный', v: '#F80000' },
    { l: 'Люминесцентный ярко-оранжевый', v: '#FFA420' },
    { l: 'Лягушка в обмороке', v: '#7B917B' },
    { l: 'Магическая мята', v: '#AAF0D1' },
    { l: 'Магнолия', v: '#F8F4FF' },
    { l: 'Маджента, Фуксия (Пурпурный)', v: '#FF00FF' },
    { l: 'Маджента Крайола', v: '#F664AF' },
    { l: 'Маисовый', v: '#EDD19C' },
    { l: 'Майский зеленый', v: '#4C9141' },
    { l: 'Макароны и сыр', v: '#FFBD88' },
    { l: 'Малахитовый', v: '#0BDA51' },
    { l: 'Малиново-красный', v: '#C51D34' },
    { l: 'Малиново-розовый', v: '#B3446C' },
    { l: 'Малиновый', v: '#DC143C' },
    { l: 'Мальва (Розовато-лиловый)', v: '#993366' },
    { l: 'Манго-танго', v: '#FF8243' },
    { l: 'Мандариновое танго', v: '#E1523D' },
    { l: 'Мандариновый', v: '#FF8800' },
    { l: 'Маренго', v: '#4C5866' },
    { l: 'Марсала', v: '#AD655F' },
    { l: 'Махагон коричневый', v: '#4C2F27' },
    { l: 'Медно-коричневый', v: '#8E402A' },
    { l: 'Медно-розовый (Бледный розовато-лиловый)', v: '#996666' },
    { l: 'Медный', v: '#B87333' },
    { l: 'Медный Крайола', v: '#DD9475' },
    { l: 'Медовая роса', v: '#F0FFF0' },
    { l: 'Медово-желтый', v: '#A98307' },
    { l: 'Медовый', v: '#FEE5AC' },
    { l: 'Международный оранжевый (Сигнальный)', v: '#FF4F00' },
    { l: 'Мертвенный индиго', v: '#00416A' },
    { l: 'Миндаль Крайола', v: '#EFDECD' },
    { l: 'Миртовый', v: '#21421E' },
    { l: 'Мовеин (Анилиновый пурпур)', v: '#EF0097' },
    { l: 'Модная фуксия', v: '#F400A1' },
    { l: 'Мокасиновый', v: '#FFE4B5' },
    { l: 'Мокрый тропический лес', v: '#17806D' },
    { l: 'Морковный', v: '#F36223' },
    { l: 'Морской зеленый', v: '#54FF9F' },
    { l: 'Морской зеленый Крайола', v: '#9FE2BF' },
    { l: 'Мурена', v: '#1C6B72' },
    { l: 'Мусульманский зеленый', v: '#009900' },
    { l: 'Мышино-серый', v: '#646B63' },
    { l: 'Мята (Цвет зеленой мяты)', v: '#98FF98' },
    { l: 'Мятно-бирюзовый', v: '#497E76' },
    { l: 'Мятно-зеленый', v: '#20603D' },
    { l: 'Мятно-кремовый', v: '#F5FFFA' },
    { l: 'Мятный', v: '#3EB489' },
    { l: 'Нарциссово-желтый', v: '#DC9D00' },
    { l: 'Насыщенный желто-зеленый', v: '#7F8F18' },
    { l: 'Насыщенный желто-коричневый', v: '#95500C' },
    { l: 'Насыщенный желто-розовый', v: '#FF7A5C' },
    { l: 'Насыщенный желтовато-зеленый', v: '#478430' },
    { l: 'Насыщенный желтый', v: '#E59E1F' },
    { l: 'Насыщенный зеленовато-желтый', v: '#CCA817' },
    { l: 'Насыщенный зеленовато-синий', v: '#00677E' },
    { l: 'Насыщенный зеленый', v: '#006B3C' },
    { l: 'Насыщенный коричневый', v: '#753313' },
    { l: 'Насыщенный красно-коричневый', v: '#7F180D' },
    { l: 'Насыщенный красно-оранжевый', v: '#FFB961' },
    { l: 'Насыщенный красно-пурпурный', v: '#9A366B' },
    { l: 'Насыщенный красный', v: '#BF2233' },
    { l: 'Насыщенный оливково-зеленый', v: '#0A4500' },
    { l: 'Насыщенный оранжево-желтый', v: '#FF8E0D' },
    { l: 'Насыщенный оранжевый', v: '#EC7C26' },
    { l: 'Насыщенный пурпурно-красный', v: '#B32851' },
    { l: 'Насыщенный пурпурно-розовый', v: '#F6768E' },
    { l: 'Насыщенный пурпурно-синий', v: '#474389' },
    { l: 'Насыщенный розовый', v: '#FD7B7C' },
    { l: 'Насыщенный синевато-зеленый', v: '#006D5B' },
    { l: 'Насыщенный синий', v: '#00538A' },
    { l: 'Насыщенный фиолетовый', v: '#53377A' },
    { l: 'Натуральная умбра', v: '#734A12' },
    { l: 'Небесная лазурь', v: '#F0FFFF' },
    { l: 'Небесно-синий', v: '#2271B3' },
    { l: 'Небесный', v: '#7FC7FF' },
    { l: 'Нежно-оливковый', v: '#6B8E23' },
    { l: 'Незрелый желтый', v: '#FFFF66' },
    { l: 'Неоново-морковный', v: '#FFA343' },
    { l: 'Нефритовый', v: '#00A86B' },
    { l: 'Ниагара', v: '#9DB1CC' },
    { l: 'Ночной синий', v: '#252850' },
    { l: 'Обычный весенний бутон', v: '#C9DC87' },
    { l: 'Огненная сиенна Крайола', v: '#EA7E5D' },
    { l: 'Огненно-красный', v: '#AF2B1E' },
    { l: 'Огненный оранжевый', v: '#FF7F49' },
    { l: 'Одуванчиковый', v: '#FDDB6D' },
    { l: 'Океанская синь', v: '#1D334A' },
    { l: 'Оксид красный', v: '#642424' },
    { l: 'Олень коричневый', v: '#59351F' },
    { l: 'Оливково-желтый', v: '#999950' },
    { l: 'Оливково-зеленый', v: '#424632' },
    { l: 'Оливково-зеленый Крайола', v: '#BAB86C' },
    { l: 'Оливково-коричневый', v: '#6F4F28' },
    { l: 'Оливково-черный', v: '#121910' },
    { l: 'Оливковый', v: '#808000' },
    { l: 'Оливковый серый', v: '#4D4234' },
    { l: 'Опаловый зеленый', v: '#015D52' },
    { l: 'Оперный розовато-лиловый', v: '#B784A7' },
    { l: 'Оранжевая заря', v: '#FD5E53' },
    { l: 'Оранжево-желтый Крайола', v: '#F8D568' },
    { l: 'Оранжево-коричневый', v: '#A65E2E' },
    { l: 'Оранжево-красный Крайола', v: '#FF2B2B' },
    { l: 'Оранжево-персиковый', v: '#FFCC99' },
    { l: 'Оранжево-розовый', v: '#FF9966' },
    { l: 'Оранжевый', v: '#FFA500' },
    { l: 'Оранжевый Крайола', v: '#FF7538' },
    { l: 'Орехово-коричневый', v: '#5B3A29' },
    { l: 'Ориент красный', v: '#B32428' },
    { l: 'Орхидея', v: '#DA70D6' },
    { l: 'Орхидея Крайола', v: '#E6A8D7' },
    { l: 'Отборный желтый', v: '#FFBA00' },
    { l: 'Отдаленно-синий', v: '#49678D' },
    { l: 'Охотничий зеленый', v: '#355E3B' },
    { l: 'Охра', v: '#CC7722' },
    { l: 'Охра желтая', v: '#AEA04B' },
    { l: 'Охра коричневая', v: '#955F20' },
    { l: 'Очень бледно-пурпурный', v: '#E6BBC1' },
    { l: 'Очень бледный зеленый', v: '#D8DEBA' },
    { l: 'Очень бледный пурпурно-синий', v: '#CBBAC5' },
    { l: 'Очень бледный синий', v: '#C1CACA' },
    { l: 'Очень бледный фиолетовый', v: '#D8B1BF' },
    { l: 'Очень глубокий желто-зеленый', v: '#002800' },
    { l: 'Очень глубокий красно-пурпурный', v: '#470736' },
    { l: 'Очень глубокий красный', v: '#4F0014' },
    { l: 'Очень глубокий пурпурно-красный', v: '#470027' },
    { l: 'Очень глубокий пурпурный', v: '#320B35' },
    { l: 'Очень светло-пурпурный', v: '#E3A9BE' },
    { l: 'Очень светлый желто-зеленый', v: '#C6DF90' },
    { l: 'Очень светлый зеленовато-синий', v: '#A3C6C0' },
    { l: 'Очень светлый зеленый', v: '#98C793' },
    { l: 'Очень светлый пурпурно-синий', v: '#BAACC7' },
    { l: 'Очень светлый синевато-зеленый', v: '#A0D6B4' },
    { l: 'Очень светлый синий', v: '#A6BDD7' },
    { l: 'Очень светлый фиолетовый', v: '#EEBEF1' },
    { l: 'Очень темно-пурпурный', v: '#230D21' },
    { l: 'Очень темный алый', v: '#560319' },
    { l: 'Очень темный желто-зеленый', v: '#132712' },
    { l: 'Очень темный зеленовато-синий', v: '#022027' },
    { l: 'Очень темный зеленый', v: '#16251C' },
    { l: 'Очень темный красно-пурпурный', v: '#270A1F' },
    { l: 'Очень темный красный', v: '#320A18' },
    { l: 'Очень темный оливковый', v: '#362C12' },
    { l: 'Очень темный пурпурно-красный', v: '#28071A' },
    { l: 'Очень темный синевато-зеленый', v: '#001D18' },
    { l: 'Очень темный хаки', v: '#4C3C18' },
    { l: 'Очищенный миндаль', v: '#FFEBCD' },
    { l: 'Панг', v: '#C7FCEC' },
    { l: 'Папоротник Крайола', v: '#71BC78' },
    { l: 'Папоротниково-зеленый', v: '#3D642D' },
    { l: 'Пастельно-бирюзовый', v: '#7FB5B5' },
    { l: 'Пастельно-желтый', v: '#EFA94A' },
    { l: 'Пастельно-зеленый', v: '#77DD77' },
    { l: 'Пастельно-оранжевый', v: '#FF7514' },
    { l: 'Пастельно-розовый', v: '#FFD1DC' },
    { l: 'Пастельно-синий', v: '#5D9B9B' },
    { l: 'Пастельно-фиолетовый', v: '#A18594' },
    { l: 'Патиново-зеленый', v: '#316650' },
    { l: 'Перекати-поле', v: '#DEAA88' },
    { l: 'Перламутрово-бежевый', v: '#6A5D4D' },
    { l: 'Перламутрово-ежевичный', v: '#6C6874' },
    { l: 'Перламутрово-зеленый', v: '#1C542D' },
    { l: 'Перламутрово-золотой', v: '#705335' },
    { l: 'Перламутрово-оранжевый', v: '#C35831' },
    { l: 'Перламутрово-розовый', v: '#B44C43' },
    { l: 'Перламутрово-рубиновый', v: '#721422' },
    { l: 'Перламутрово-фиолетовый', v: '#8673A1' },
    { l: 'Перламутровый горечавково-синий', v: '#2A6478' },
    { l: 'Перламутровый медный', v: '#763C28' },
    { l: 'Перламутровый мышино-серый', v: '#898176' },
    { l: 'Перламутровый ночной', v: '#102C54' },
    { l: 'Перламутровый опаловый', v: '#193737' },
    { l: 'Перламутровый светло-серый', v: '#9C9C9C' },
    { l: 'Перламутровый темно-серый', v: '#828282' },
    { l: 'Персидский зеленый', v: '#00A693' },
    { l: 'Персидский индиго', v: '#32127A' },
    { l: 'Персидский красный', v: '#CC3333' },
    { l: 'Персидский розовый', v: '#FE28A2' },
    { l: 'Персидский синий', v: '#6600FF' },
    { l: 'Персиковый', v: '#FFE5B4' },
    { l: 'Персиковый Крайола', v: '#FFCFAB' },
    { l: 'Перу', v: '#CD853F' },
    { l: 'Песок пустыни', v: '#EFCDB8' },
    { l: 'Песочно-желтый', v: '#C6A664' },
    { l: 'Песочный', v: '#FCDD76' },
    { l: 'Песочный серо-коричневый', v: '#967117' },
    { l: 'Пигментный зеленый', v: '#00A550' },
    { l: 'Пихтовый зеленый', v: '#31372B' },
    { l: 'Пламенная маджента Крайола', v: '#F8173E' },
    { l: 'Платиново-серый', v: '#7F7679' },
    { l: 'Побег папайи', v: '#FFEFD5' },
    { l: 'Полумрак Крайола', v: '#8A795D' },
    { l: 'Полуночно-синий', v: '#003366' },
    { l: 'Полуночный синий Крайола', v: '#1A4876' },
    { l: 'Полуночный черный', v: '#191970' },
    { l: 'Последний вздох Жако', v: '#FF9218' },
    { l: 'Почти черный', v: '#131313' },
    { l: 'Призрачно-белый', v: '#F8F8FF' },
    { l: 'Пурпурная пицца', v: '#FF00CC' },
    { l: 'Пурпурно-белый', v: '#FADBC8' },
    { l: 'Пурпурно-красный', v: '#75151E' },
    { l: 'Пурпурно-серый', v: '#88706B' },
    { l: 'Пурпурно-синий', v: '#20155E' },
    { l: 'Пурпурно-фиолетовый', v: '#4A192C' },
    { l: 'Пурпурно-черный', v: '#1B1116' },
    { l: 'Пурпурное горное величие', v: '#9D81BA' },
    { l: 'Пурпурное сердце', v: '#7442C8' },
    { l: 'Пурпурный', v: '#800080' },
    { l: 'Пшеничный', v: '#F5DEB3' },
    { l: 'Пылкий красно-оранжевый', v: '#F75E25' },
    { l: 'Пылкий розовый', v: '#FF7E93' },
    { l: 'Пыльно-серый', v: '#7D7F7D' },
    { l: 'Пыльный голубой', v: '#B0E0E6' },
    { l: 'Пюсовый', v: '#CC8899' },
    { l: 'Радикальный красный', v: '#FF496C' },
    { l: 'Рапсово-желтый', v: '#F3DA0B' },
    { l: 'Резедово-зеленый', v: '#587246' },
    { l: 'Ржаво-коричневый', v: '#B7410E' },
    { l: 'Розовато-лиловый Крайола', v: '#EF98AA' },
    { l: 'Розовато-серый', v: '#C8A696' },
    { l: 'Розовая гвоздика', v: '#FFAACC' },
    { l: 'Розовая долина', v: '#AB4E52' },
    { l: 'Розовая фуксия', v: '#FF77FF' },
    { l: 'Розово-золотой', v: '#B76E79' },
    { l: 'Розово-коричневый', v: '#BC8F8F' },
    { l: 'Розово-лавандовый', v: '#FFF0F5' },
    { l: 'Розово-серо-коричневый', v: '#905D5D' },
    { l: 'Розово-фиолетовый', v: '#EE82EE' },
    { l: 'Розово-эбонитовый', v: '#674846' },
    { l: 'Розовый', v: '#FFC0CB' },
    { l: 'Розовый (Пощекочи меня)', v: '#FC89AC' },
    { l: 'Розовый антик', v: '#D36E70' },
    { l: 'Розовый кварц', v: '#AA98A9' },
    { l: 'Розовый лес', v: '#65000B' },
    { l: 'Розовый Маунтбэттена', v: '#997A8D' },
    { l: 'Розовый поросенок', v: '#FDDDE6' },
    { l: 'Розовый фламинго', v: '#FC74FD' },
    { l: 'Розовый щербет', v: '#F78FA7' },
    { l: 'Рубиново-красный', v: '#9B111E' },
    { l: 'Румянец', v: '#DE5D83' },
    { l: 'Рыжий', v: '#D77D31' },
    { l: 'Салатовый', v: '#99FF99' },
    { l: 'Сангина', v: '#92000A' },
    { l: 'Сапфирово-синий', v: '#1D1E33' },
    { l: 'Сапфировый', v: '#082567' },
    { l: 'Светлая вишня', v: '#DE3163' },
    { l: 'Светлая мальва (Светло-розовато-лиловый)', v: '#DCD0FF' },
    { l: 'Светлая Сиена (Почти чистый оранжевый)', v: '#E28B00' },
    { l: 'Светлая слива', v: '#DDA0DD' },
    { l: 'Светлая слоновая кость', v: '#E6D690' },
    { l: 'Светло-бирюзовый', v: '#40E0D0' },
    { l: 'Светло-вишневый Крайола', v: '#DD4492' },
    { l: 'Светло-голубой', v: '#87CEFA' },
    { l: 'Светло-желтый', v: '#FFFFE0' },
    { l: 'Светло-желтый золотистый', v: '#FAFAD2' },
    { l: 'Светло-зеленый', v: '#90EE90' },
    { l: 'Светло-золотистый', v: '#FFEC8B' },
    { l: 'Светло-коралловый', v: '#FFBCAD' },
    { l: 'Светло-коричневый', v: '#987654' },
    { l: 'Светло-морковный', v: '#ED9121' },
    { l: 'Светло-оливковый', v: '#846A20' },
    { l: 'Светло-песочный', v: '#FDEAA8' },
    { l: 'Светло-пурпурный', v: '#BA7FA2' },
    { l: 'Светло-розовая фуксия', v: '#F984EF' },
    { l: 'Светло-розовый', v: '#FFB6C1' },
    { l: 'Светло-серебристый', v: '#C9C0BB' },
    { l: 'Светло-серый', v: '#BBBBBB' },
    { l: 'Светло-синий', v: '#A6CAF0' },
    { l: 'Светло-тициановый', v: '#D84B20' },
    { l: 'Светло-фиолетовый', v: '#876C99' },
    { l: 'Светлое зеленое море', v: '#20B2AA' },
    { l: 'Светлый аспидно-серый', v: '#778899' },
    { l: 'Светлый глубокий желтый', v: '#FFD35F' },
    { l: 'Светлый джинсовый', v: '#2B6CC4' },
    { l: 'Светлый желто-зеленый', v: '#DCD36A' },
    { l: 'Светлый желто-коричневый', v: '#BB8B54' },
    { l: 'Светлый желто-розовый', v: '#FFB28B' },
    { l: 'Светлый зеленовато-белый', v: '#BAAF96' },
    { l: 'Светлый зеленовато-желтый', v: '#FFDE5A' },
    { l: 'Светлый зеленовато-синий', v: '#649A9E' },
    { l: 'Светлый карминово-розовый', v: '#E66761' },
    { l: 'Светлый коричневато-серый', v: '#8B6D5C' },
    { l: 'Светлый коричневый', v: '#A86540' },
    { l: 'Светлый красно-коричневый', v: '#AA6651' },
    { l: 'Светлый красно-пурпурный', v: '#BB6C8A' },
    { l: 'Светлый малиново-красный', v: '#E63244' },
    { l: 'Светлый оливково-коричневый', v: '#945D0B' },
    { l: 'Светлый оливковый серый', v: '#887359' },
    { l: 'Светлый оранжевый', v: '#FFA161' },
    { l: 'Светлый пурпурно-розовый', v: '#FFA8AF' },
    { l: 'Светлый пурпурно-серый', v: '#C8A99E' },
    { l: 'Светлый пурпурно-синий', v: '#837DA2' },
    { l: 'Светлый розово-лиловый', v: '#EA899A' },
    { l: 'Светлый серо-желто-коричневый', v: '#B48764' },
    { l: 'Светлый серо-коричневый', v: '#946B54' },
    { l: 'Светлый серо-красно-коричневый', v: '#966A57' },
    { l: 'Светлый серо-красный', v: '#B17267' },
    { l: 'Светлый серо-оливковый', v: '#8B734B' },
    { l: 'Светлый серо-пурпурно-красный', v: '#B27070' },
    { l: 'Светлый серо-синий', v: '#84C3BE' },
    { l: 'Светлый серый', v: '#D7D7D7' },
    { l: 'Светлый сине-серый', v: '#6C92AF' },
    { l: 'Светлый синевато-зеленый', v: '#669E85' },
    { l: 'Светлый синевато-серый', v: '#BEADA1' },
    { l: 'Светлый синий', v: '#ADD8E6' },
    { l: 'Светлый стальной синий', v: '#B0C4DE' },
    { l: 'Светлый телегрей', v: '#D0D0D0' },
    { l: 'Светлый хаки', v: '#F0E68C' },
    { l: 'Светлый циан', v: '#E0FFFF' },
    { l: 'Селадон', v: '#ACE1AF' },
    { l: 'Сепия (Каракатица)', v: '#704214' },
    { l: 'Сепия коричневый', v: '#382C1E' },
    { l: 'Сепия Крайола', v: '#A5694F' },
    { l: 'Серая белка', v: '#78858B' },
    { l: 'Серая спаржа', v: '#465945' },
    { l: 'Серая умбра', v: '#332F2C' },
    { l: 'Серебристо-серый', v: '#8A9597' },
    { l: 'Серебряный', v: '#C0C0C0' },
    { l: 'Серебряный Крайола', v: '#CDC5C2' },
    { l: 'Серо-бежевый', v: '#9E9764' },
    { l: 'Серобуромалиновый', v: '#735184' },
    { l: 'Серовато-желто-зеленый', v: '#90845B' },
    { l: 'Серовато-желто-коричневый', v: '#785840' },
    { l: 'Серовато-желто-розовый', v: '#D39B85' },
    { l: 'Серовато-желтый', v: '#CEA262' },
    { l: 'Серовато-зеленовато-желтый', v: '#C4A55F' },
    { l: 'Серовато-зеленый', v: '#575E4E' },
    { l: 'Серовато-коричневый', v: '#5A3D30' },
    { l: 'Серовато-красно-коричневый', v: '#5E3830' },
    { l: 'Серовато-красно-оранжевый', v: '#B85D43' },
    { l: 'Серовато-красно-пурпурный', v: '#7D4D5D' },
    { l: 'Серовато-красный', v: '#8C4743' },
    { l: 'Серовато-оливковый', v: '#52442C' },
    { l: 'Серовато-оранжевый', v: '#C2A894' },
    { l: 'Серовато-пурпурно-красный', v: '#8C4852' },
    { l: 'Серовато-пурпурно-розовый', v: '#CC9293' },
    { l: 'Серовато-пурпурно-синий', v: '#413D51' },
    { l: 'Серовато-пурпурный', v: '#72525C' },
    { l: 'Серовато-розовый', v: '#CF9B8F' },
    { l: 'Серовато-синий', v: '#4A545C' },
    { l: 'Серовато-фиолетовый', v: '#46394B' },
    { l: 'Сероватый оливково-зеленый', v: '#48442D' },
    { l: 'Серое окно', v: '#9DA1AA' },
    { l: 'Серый', v: '#808080' },
    { l: 'Серый бетон', v: '#686C5E' },
    { l: 'Серый зеленый чай', v: '#CADABA' },
    { l: 'Серый коричневый', v: '#403A3A' },
    { l: 'Серый Крайола', v: '#95918C' },
    { l: 'Серый мох', v: '#6C7059' },
    { l: 'Серый нейтральный', v: '#A0A0A4' },
    { l: 'Серый оливковый', v: '#3E3B32' },
    { l: 'Серый синий', v: '#26252D' },
    { l: 'Серый хаки', v: '#6A5F31' },
    { l: 'Серый шелк', v: '#CAC4B0' },
    { l: 'Серый шифер, аспидно-серый', v: '#708090' },
    { l: 'Сигнальный желтый', v: '#E5BE01' },
    { l: 'Сигнальный зеленый', v: '#317F43' },
    { l: 'Сигнальный коричневый', v: '#6C3B2A' },
    { l: 'Сигнальный красный', v: '#A52019' },
    { l: 'Сигнальный оранжевый', v: '#FF9900' },
    { l: 'Сигнальный серый', v: '#969992' },
    { l: 'Сигнальный синий', v: '#1E2460' },
    { l: 'Сигнальный фиолетовый', v: '#924E7D' },
    { l: 'Сигнальный черный', v: '#282828' },
    { l: 'Сиена', v: '#A0522D' },
    { l: 'Сиена жженая', v: '#E97451' },
    { l: 'Сизый', v: '#79A0C1' },
    { l: 'Сине-зеленый', v: '#1F3A3D' },
    { l: 'Сине-зеленый Крайола', v: '#0D98BA' },
    { l: 'Сине-лиловый', v: '#8A2BE2' },
    { l: 'Сине-серый Крайола', v: '#6699CC' },
    { l: 'Сине-сиреневый', v: '#6C4675' },
    { l: 'Сине-фиолетовый Крайола', v: '#7366BD' },
    { l: 'Синевато-белый', v: '#F9DFCF' },
    { l: 'Синевато-серый', v: '#7D746D' },
    { l: 'Синевато-черный', v: '#151719' },
    { l: 'Синий', v: '#0000FF' },
    { l: 'Синий-синий иней', v: '#AFDAFC' },
    { l: 'Синий Градуса', v: '#007DFF' },
    { l: 'Синий Клейна', v: '#3A75C4' },
    { l: 'Синий Крайола', v: '#1F75FE' },
    { l: 'Синий серый', v: '#474B4E' },
    { l: 'Синий цвета яиц странствующего дрозда', v: '#1FCECB' },
    { l: 'Синий чирок', v: '#18A7B5' },
    { l: 'Синий экран смерти', v: '#122FAA' },
    { l: 'Синяя лазурь (Лазурно-голубой)', v: '#2A52BE' },
    { l: 'Синяя пыль', v: '#003399' },
    { l: 'Синяя сталь', v: '#4682B4' },
    { l: 'Синяя Элис', v: '#F0F8FF' },
    { l: 'Сиреневый', v: '#C8A2C8' },
    { l: 'Сияющая орхидея', v: '#B565A7' },
    { l: 'Скандальный оранжевый', v: '#FF6E4A' },
    { l: 'Скарлет', v: '#FC2847' },
    { l: 'Сладкая вата', v: '#FFBCD9' },
    { l: 'Сланцево-серый', v: '#434750' },
    { l: 'Сливовый', v: '#660066' },
    { l: 'Сливовый Крайола', v: '#8E4585' },
    { l: 'Сливочно-кремовый', v: '#F2DDC6' },
    { l: 'Сливочный', v: '#F2E8C9' },
    { l: 'Слоновая кость', v: '#FFFFF0' },
    { l: 'Снежно-синий', v: '#ACE5EE' },
    { l: 'Солнечно-желтый', v: '#F39F18' },
    { l: 'Сомон', v: '#EFAF8C' },
    { l: 'Сосновый зеленый', v: '#2C5545' },
    { l: 'Сочный каштановый Крайола', v: '#B94E48' },
    { l: 'Спаржа', v: '#7BA05B' },
    { l: 'Спаржа Крайола', v: '#87A96B' },
    { l: 'Средний карминный', v: '#AF4035' },
    { l: 'Средний персидский синий', v: '#0067A5' },
    { l: 'Средний пурпурный', v: '#9370D8' },
    { l: 'Средний серый', v: '#817066' },
    { l: 'Стальной синий', v: '#231A24' },
    { l: 'Старинный розовый', v: '#C08081' },
    { l: 'Старое золото', v: '#CFB53B' },
    { l: 'Старое кружево', v: '#FDF5E6' },
    { l: 'Старый лен', v: '#EEDC82' },
    { l: 'Сырая охра', v: '#D68A59' },
    { l: 'Сырая умбра', v: '#714B23' },
    { l: 'Телегрей', v: '#909090' },
    { l: 'Телемагента', v: '#CF3476' },
    { l: 'Темная Византия', v: '#5D3954' },
    { l: 'Темная орхидея', v: '#9932CC' },
    { l: 'Темно-алый', v: '#CB2821' },
    { l: 'Темно-бирюзовый', v: '#116062' },
    { l: 'Темно-голубой', v: '#3B83BD' },
    { l: 'Темно-грушевый', v: '#D8A903' },
    { l: 'Темно-желтый', v: '#B07D2B' },
    { l: 'Темно-зеленый', v: '#013220' },
    { l: 'Темно-каштановый', v: '#986960' },
    { l: 'Темно-коралловый', v: '#CD5B45' },
    { l: 'Темно-коричневый', v: '#654321' },
    { l: 'Темно-красный', v: '#8B0000' },
    { l: 'Темно-лазурный', v: '#08457E' },
    { l: 'Темно-лососевый', v: '#E9967A' },
    { l: 'Темно-мандариновый', v: '#FFA812' },
    { l: 'Темно-оливковый', v: '#556832' },
    { l: 'Темно-оранжевый', v: '#FF8C00' },
    { l: 'Темно-персиковый', v: '#FFDAB9' },
    { l: 'Темно-пурпурный', v: '#472A3F' },
    { l: 'Темно-розовый', v: '#E75480' },
    { l: 'Темно-серая мальва (Розовато-лилово-серый)', v: '#915F6D' },
    { l: 'Темно-серо-коричневый', v: '#483C32' },
    { l: 'Темно-серый', v: '#49423D' },
    { l: 'Темно-синий', v: '#002137' },
    { l: 'Темно-синий (Цвет формы морских офицеров)', v: '#000080' },
    { l: 'Темно-синий Крайола', v: '#1974D2' },
    { l: 'Темно-фиолетовый', v: '#9400D3' },
    { l: 'Темное зеленое море', v: '#8FBC8F' },
    { l: 'Темный аспидно-синий', v: '#483D8B' },
    { l: 'Темный весенне-зеленый', v: '#177245' },
    { l: 'Темный желто-зеленый', v: '#57A639' },
    { l: 'Темный желто-коричневый', v: '#918151' },
    { l: 'Темный желто-розовый', v: '#CC6C5C' },
    { l: 'Темный желтовато-зеленый', v: '#304B26' },
    { l: 'Темный желтовато-коричневый', v: '#3F2512' },
    { l: 'Темный зеленовато-желто-зеленый', v: '#313830' },
    { l: 'Темный зеленовато-желтый', v: '#9B8127' },
    { l: 'Темный зеленовато-серый', v: '#45433B' },
    { l: 'Темный зеленовато-синий', v: '#003841' },
    { l: 'Темный зеленый', v: '#203A27' },
    { l: 'Темный зеленый чай', v: '#BADBAD' },
    { l: 'Темный золотарник (Темно-золотой)', v: '#B8860B' },
    { l: 'Темный индиго', v: '#310062' },
    { l: 'Темный Коричневый', v: '#35170C' },
    { l: 'Темный красно-коричневый', v: '#321011' },
    { l: 'Темный красно-оранжевый', v: '#9B2F1F' },
    { l: 'Темный красно-пурпурный', v: '#4F273A' },
    { l: 'Темный красно-серый', v: '#523C36' },
    { l: 'Темный красный', v: '#681C23' },
    { l: 'Темный маджента', v: '#8B008B' },
    { l: 'Темный мандарин', v: '#EA7500' },
    { l: 'Темный оливково-зеленый', v: '#232C16' },
    { l: 'Темный оливково-коричневый', v: '#302112' },
    { l: 'Темный оранжево-желтый', v: '#C37629' },
    { l: 'Темный пастельно-зеленый', v: '#03C03C' },
    { l: 'Темный пурпурно-красный', v: '#5B1E31' },
    { l: 'Темный пурпурно-розовый', v: '#C76574' },
    { l: 'Темный пурпурно-серый', v: '#564042' },
    { l: 'Темный пурпурно-синий', v: '#1A162A' },
    { l: 'Темный пурпурно-фиолетовый', v: '#660099' },
    { l: 'Темный розовый', v: '#C76864' },
    { l: 'Темный серо-желтый', v: '#A47C45' },
    { l: 'Темный серо-коричневый', v: '#32221A' },
    { l: 'Темный серо-красно-коричневый', v: '#371F1C' },
    { l: 'Темный серо-красный', v: '#482A2A' },
    { l: 'Темный серо-оливково-зеленый', v: '#27261A' },
    { l: 'Темный серо-оливковый', v: '#2B2517' },
    { l: 'Темный серо-синий', v: '#2C3337' },
    { l: 'Темный синевато-зеленый', v: '#013A33' },
    { l: 'Темный синевато-черный', v: '#464544' },
    { l: 'Темный телегрей', v: '#82898F' },
    { l: 'Темный терракотовый', v: '#4E3B31' },
    { l: 'Темный ультрамариновый', v: '#00008B' },
    { l: 'Темный хаки', v: '#BDB76B' },
    { l: 'Темный циан', v: '#008B8B' },
    { l: 'Темный черновато-пурпурный', v: '#452D35' },
    { l: 'Темный янтарь', v: '#FF7E00' },
    { l: 'Терракота', v: '#CC4E5C' },
    { l: 'Терракотовый', v: '#904D30' },
    { l: 'Тиффани', v: '#0ABAB5' },
    { l: 'Тихоокеанский синий', v: '#1CA9C9' },
    { l: 'Тициановый', v: '#D53E07' },
    { l: 'Томатно-красный', v: '#A12312' },
    { l: 'Томатный', v: '#FF6347' },
    { l: 'Травяной', v: '#5DA130' },
    { l: 'Травяной (Очень темный лимонный зеленый)', v: '#006400' },
    { l: 'Травяной зеленый', v: '#35682D' },
    { l: 'Транспортно-желтый', v: '#FAD201' },
    { l: 'Транспортный зеленый', v: '#308446' },
    { l: 'Транспортный красный', v: '#CC0605' },
    { l: 'Транспортный оранжевый', v: '#F54021' },
    { l: 'Транспортный пурпурный', v: '#A03472' },
    { l: 'Транспортный серый', v: '#8D948D' },
    { l: 'Транспортный синий', v: '#063971' },
    { l: 'Транспортный черный', v: '#1E1E1E' },
    { l: 'Трилистник Крайола', v: '#45CEA2' },
    { l: 'Тростниково-зеленый', v: '#6C7156' },
    { l: 'Турецкий розовый', v: '#B57281' },
    { l: 'Тускло-амарантово-розовый', v: '#DDBEC3' },
    { l: 'Тускло-розовый', v: '#FFE4E1' },
    { l: 'Тусклый мандарин', v: '#F28500' },
    { l: 'Тусклый пурпурный', v: '#AE848B' },
    { l: 'Тусклый серый', v: '#696969' },
    { l: 'Тыква (Тыквенный)', v: '#FF7518' },
    { l: 'Ультрамариново-синий', v: '#20214F' },
    { l: 'Ультрамариновый', v: '#120A8F' },
    { l: 'Умбра жженая', v: '#8A3324' },
    { l: 'Умеренно-бирюзовый', v: '#48D1CC' },
    { l: 'Умеренно-зеленое море', v: '#3CB371' },
    { l: 'Умеренно-оливковый', v: '#5E490F' },
    { l: 'Умеренно-темный пурпурный', v: '#803E75' },
    { l: 'Умеренно зеленый', v: '#C0DCC0' },
    { l: 'Умеренный аквамариновый', v: '#66CDAA' },
    { l: 'Умеренный аспидно-синий', v: '#7B68EE' },
    { l: 'Умеренный весенний зеленый', v: '#00FA9A' },
    { l: 'Умеренный желто-зеленый', v: '#8B8940' },
    { l: 'Умеренный желто-коричневый', v: '#7D512D' },
    { l: 'Умеренный желто-розовый', v: '#EE9374' },
    { l: 'Умеренный желтовато-зеленый', v: '#657F4B' },
    { l: 'Умеренный желтый', v: '#D79D41' },
    { l: 'Умеренный зеленовато-желтый', v: '#C4A43D' },
    { l: 'Умеренный зеленовато-синий', v: '#30626B' },
    { l: 'Умеренный зеленый', v: '#386646' },
    { l: 'Умеренный коричневый', v: '#673923' },
    { l: 'Умеренный красно-оранжевый', v: '#D35339' },
    { l: 'Умеренный красно-пурпурный', v: '#8C4566' },
    { l: 'Умеренный красный', v: '#AB343A' },
    { l: 'Умеренный оливково-зеленый', v: '#434B1B' },
    { l: 'Умеренный оранжево-желтый', v: '#F7943C' },
    { l: 'Умеренный оранжевый', v: '#E8793E' },
    { l: 'Умеренный пурпурно-красный', v: '#A73853' },
    { l: 'Умеренный пурпурно-розовый', v: '#E28090' },
    { l: 'Умеренный пурпурно-синий', v: '#423C63' },
    { l: 'Умеренный пурпурный', v: '#7F4870' },
    { l: 'Умеренный розовый', v: '#EE9086' },
    { l: 'Умеренный серо-коричневый', v: '#674C47' },
    { l: 'Умеренный синевато-зеленый', v: '#2F6556' },
    { l: 'Умеренный синий', v: '#395778' },
    { l: 'Умеренный фиолетово-красный', v: '#C71585' },
    { l: 'Умеренный фиолетовый', v: '#543964' },
    { l: 'Умеренный цвет орхидеи', v: '#BA55D3' },
    { l: 'Фалунский красный', v: '#801818' },
    { l: 'Фанданго', v: '#B55489' },
    { l: 'Фельдграу', v: '#4D5D53' },
    { l: 'Фиалковый', v: '#EA8DF7' },
    { l: 'Фиолетово-баклажанный', v: '#991199' },
    { l: 'Фиолетово-красный Крайола', v: '#F75394' },
    { l: 'Фиолетово-сизый', v: '#8000FF' },
    { l: 'Фиолетово-синий', v: '#354D73' },
    { l: 'Фиолетово-синий Крайола', v: '#324AB2' },
    { l: 'Фиолетовый', v: '#8B00FF' },
    { l: 'Фиолетовый Крайола (Пурпурный)', v: '#926EAE' },
    { l: 'Фисташковый', v: '#BEF574' },
    { l: 'Французский розовый', v: '#F64A8A' },
    { l: 'Фталоцианиновый зеленый', v: '#123524' },
    { l: 'Фузи-вузи', v: '#CC6666' },
    { l: 'Фуксия (Фуксин)', v: '#F754E1' },
    { l: 'Фуксия Крайола', v: '#C364C5' },
    { l: 'Хаки', v: '#806B2A' },
    { l: 'Хромовый зеленый', v: '#2E3A23' },
    { l: 'Цвет блошиного брюшка', v: '#4E1609' },
    { l: 'Цвет ВКонтакте', v: '#4D7198' },
    { l: 'Цвет влюбленной жабы', v: '#3CAA3C' },
    { l: 'Цвет детской неожиданности', v: '#F7F21A' },
    { l: 'Цвет елки', v: '#2A5C03' },
    { l: 'Цвет желтого школьного автобуса', v: '#FFD800' },
    { l: 'Цвет загара (Желто-коричневый)', v: '#D2B48C' },
    { l: 'Цвет загара Крайола', v: '#FAA76C' },
    { l: 'Цвет Красного моря', v: '#1F4037' },
    { l: 'Цвет маленького мандарина', v: '#FFA474' },
    { l: 'Цвет медвежьего ушка', v: '#834D18' },
    { l: 'Цвет мокрого асфальта', v: '#505050' },
    { l: 'Цвет морской волны (Аква)', v: '#008CF0' },
    { l: 'Цвет морской раковины (Морская пена)', v: '#FFF5EE' },
    { l: 'Цвет окраски птицы чирок (Сине-зеленый)', v: '#008080' },
    { l: 'Цветочный белый', v: '#FFFAF0' },
    { l: 'Цвет пергидрольной блондинки', v: '#EEE6A3' },
    { l: 'Цвет пожарной машины', v: '#CE2029' },
    { l: 'Цвет слоновой кости (Айвори)', v: '#FFFDDF' },
    { l: 'Цвет суеты', v: '#E3256B' },
    { l: 'Цвет Твиттера', v: '#1FAEE9' },
    { l: 'Цвет Фейсбука', v: '#3B5998' },
    { l: 'Цвет Хабрахабра', v: '#78A2B7' },
    { l: 'Цвет Черного моря', v: '#1A4780' },
    { l: 'Цвет шампанского', v: '#FCFCEE' },
    { l: 'Цвет шелковистых нитевидных пестиков початков неспелой кукурузы', v: '#FFF8DC' },
    { l: 'Цвет яйца дрозда', v: '#00CCCC' },
    { l: 'Цвет Яндекса', v: '#FFCC00' },
    { l: 'Цементно-серый (Цементный)', v: '#7D8471' },
    { l: 'Циан, Цвет морской волны', v: '#00FFFF' },
    { l: 'Цинково-желтый', v: '#F8F32B' },
    { l: 'Циннвальдит', v: '#EBC2AF' },
    { l: 'Циннвальдитово-розовый', v: '#FFCBBB' },
    { l: 'Черно-зеленый', v: '#343E40' },
    { l: 'Черно-коричневый', v: '#212121' },
    { l: 'Черно-красный', v: '#412227' },
    { l: 'Черно-оливковый', v: '#3B3C36' },
    { l: 'Черно-серый', v: '#23282B' },
    { l: 'Черно-синий', v: '#18171C' },
    { l: 'Черновато-зеленый', v: '#141613' },
    { l: 'Черновато-красный', v: '#1F0E11' },
    { l: 'Черновато-пурпурный', v: '#1D1018' },
    { l: 'Черновато-синий', v: '#161A1E' },
    { l: 'Черный', v: '#000000' },
    { l: 'Черный янтарь', v: '#0A0A0A' },
    { l: 'Чертополох', v: '#D8BFD8' },
    { l: 'Чертополох Крайола', v: '#EBC7DF' },
    { l: 'Шамуа', v: '#A08040' },
    { l: 'Шапка Деда Мороза', v: '#CA3A27' },
    { l: 'Шапка Санта-Клауса', v: '#ED4830' },
    { l: 'Шартрез, Ядовито-зеленый', v: '#7FFF00' },
    { l: 'Шафраново-желтый', v: '#F5D033' },
    { l: 'Шафрановый', v: '#F4C430' },
    { l: 'Шелковица Крайола', v: '#C54B8C' },
    { l: 'Шокирующий розовый Крайола', v: '#FB7EFD' },
    { l: 'Шоколадно-коричневый', v: '#45322E' },
    { l: 'Шоколадный', v: '#D2691E' },
    { l: 'Экрю', v: '#CDB891' },
    { l: 'Экстравагантный розовый Крайола', v: '#FF33CC' },
    { l: 'Электрик', v: '#7DF9FF' },
    { l: 'Электрик лайм (Лаймовый)', v: '#CCFF00' },
    { l: 'Электрик лайм Крайола', v: '#CEFF1D' },
    { l: 'Ядовито-зеленый', v: '#40826D' },
    { l: 'Янтарный', v: '#FFBF00' },
    { l: 'Яркий желто-зеленый', v: '#93AA00' },
    { l: 'Яркий желто-розовый', v: '#FF845C' },
    { l: 'Яркий зеленовато-желтый', v: '#F4C800' },
    { l: 'Яркий зеленый', v: '#007D34' },
    { l: 'Яркий красно-оранжевый', v: '#F13A13' },
    { l: 'Яркий красно-пурпурный', v: '#7E0059' },
    { l: 'Яркий красный', v: '#C10020' },
    { l: 'Яркий оранжево-желтый', v: '#FF8E00' },
    { l: 'Яркий оранжевый', v: '#FF6800' },
    { l: 'Яркий пурпурно-красный', v: '#D5265B' },
    { l: 'Яркий пурпурный', v: '#943391' },
    { l: 'Яркий синевато-зеленый', v: '#00836E' },
    { l: 'Яркий фиолетовый Крайола', v: '#8F509D' },
    { l: 'Ярко-бирюзовый', v: '#08E8DE' },
    { l: 'Ярко-желтый', v: '#FFB300' },
    { l: 'Ярко-зеленый', v: '#66FF00' },
    { l: 'Ярко-мандариновый', v: '#FFA089' },
    { l: 'Ярко-розовый', v: '#FC0FC0' },
    { l: 'Ярко-синий', v: '#007CAD' },
    { l: 'Ярко-сиреневый', v: '#E0B0FF' },
    { l: 'Ярко-фиолетовый', v: '#CD00CD' }
]
